@@ -50,7 +50,8 @@ var _ = ginkgo.BeforeSuite(func(done ginkgo.Done) {
 	testEnv = &envtest.Environment{
 		ErrorIfCRDPathMissing: true,
 		CRDDirectoryPaths: []string{
-			filepath.Join(".", "vendor", "github.com", "open-cluster-management", "api", "work", "v1"),
+			filepath.Join(".", "deploy", "webhook"),
+			filepath.Join(".", "deploy", "spoke"),
 		},
 	}
 
